==> openwebbeans-1.7.6-source-release.zip: openwebbeans-1.7.6/webbeans-impl/src/test/java/org/apache/webbeans/test/portable/scopeextension/ExternalTestScopeExtension.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.webbeans.test.portable.scopeextension;

import javax.enterprise.event.Observes;
import javax.enterprise.inject.spi.AfterBeanDiscovery;
import javax.enterprise.inject.spi.BeanManager;
import javax.enterprise.inject.spi.BeforeBeanDiscovery;
import javax.enterprise.inject.spi.Extension;

import org.junit.Assert;


public class ExternalTestScopeExtension implements Extension 
{
    public void addViewScoped(@Observes BeforeBeanDiscovery beforeBeanDiscovery, BeanManager beanManager)
    {
        // see OWB-622 it's expected that the BeanManager already exists even in BeforeBeanDiscovery.
        Assert.assertNotNull(beanManager);

        beforeBeanDiscovery.addScope(ExternalTestScoped.class, true, true);
    }
    
    public void registerViewContext(@Observes AfterBeanDiscovery afterBeanDiscovery)
    {
        afterBeanDiscovery.addContext(new ExternalTestScopeContext(true));
        afterBeanDiscovery.addContext(new ExternalTestScopeContext(false));
    }
}

==> openwebbeans-4.0.3-source-release.zip: openwebbeans-4.0.3/webbeans-impl/src/test/java/org/apache/webbeans/test/portable/scopeextension/ExternalTestScopeExtension.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.webbeans.test.portable.scopeextension;

import jakarta.enterprise.event.Observes;
import jakarta.enterprise.inject.spi.AfterBeanDiscovery;
import jakarta.enterprise.inject.spi.BeanManager;
import jakarta.enterprise.inject.spi.BeforeBeanDiscovery;
import jakarta.enterprise.inject.spi.Extension;

import org.junit.Assert;


public class ExternalTestScopeExtension implements Extension 
{
    public void addViewScoped(@Observes BeforeBeanDiscovery beforeBeanDiscovery, BeanManager beanManager)
    {
        // see OWB-622 it's expected that the BeanManager already exists even in BeforeBeanDiscovery.
        Assert.assertNotNull(beanManager);

        beforeBeanDiscovery.addScope(ExternalTestScoped.class, true, true);
    }
    
    public void registerViewContext(@Observes AfterBeanDiscovery afterBeanDiscovery)
    {
        afterBeanDiscovery.addContext(new ExternalTestScopeContext(true));
        afterBeanDiscovery.addContext(new ExternalTestScopeContext(false));
    }
}
